{% extends "base.html" %} {% block main %}

## Provide documentation

Thank you so much for offering your time. This section looks at contributions which may involve code that is not part of the Sketching library distribution or supporting code itself.

### Translate

We invite translators to migrate existing documentation to new languages for which a prior translation is not available. Please open an issue and indicate the following:

- What section of documentation you are hoping to volunteer.
- What language you are offering to provide translation.
- Confirm that you have prior skill in this language and will not use machine translation.

Be sure to add the tag "Documentation" to your issue.

### Add an example

Short examples for specific Sketching functionality help developers of all skill levels use our open source tools. There are multiple ways to contribute. First, you may respond to an open issue asking for an example within our tracker to indicate you are volunteering. Second, you may submit an example you've made even though a prior issue was not open by opening an issue with the following:

- Description of the functionality for which the example is being provided.
- The code for the example.
- Draft of accompanying text (if applicable).
- Suggestion on where within Sketching's website or repository the example should go.
Finally, you may report an issue with existing examples by [opening an issue](https://codeberg.org/sketching/Sketchingpy/issues) with the URL of the problem along with a description of the problem. Thank you very much!

### Write documentation

Carefully written documentation benefits developers of all skill levels. There are multiple ways to contribute. First, you may respond to an open issue asking for documentation within our tracker to indicate you are volunteering. Second, you may submit a new issue with the following:

- Description of the functionality for which the documentation is being provided.
- Code snippet (if applicable).
- Draft of accompanying text.
- Suggestion on where within Sketching's website or repository the documentation should go.
Finally, you may report an issue with existing documentation by [opening an issue](https://codeberg.org/sketching/Sketchingpy/issues) with the URL of the problem along with a description of the problem. Thank you so much for your time.

### Related materials

- Code of Conduct
- Contribution Guidelines and Agreement
- Governance
- README

{% endblock %}